; docformat = 'rst'
;+
; This is an example program to demonstrate how to create plot within a plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "plot_within_plot.pro" and run it like this::
;       IDL> .RUN plot_within_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 15 February 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Plot_Within_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   y = cgDemoData(1)
   x = Findgen(N_Elements(y))
   zoomIn = [50,65]
   
   ; Create a display window.
   cgDisplay
   
   ; Find the maximum value of the plot
   maxData = Max(y)
   
   ; Plot the data, leaving room at the top of the plot for
   ; the zoom plot.
   cgPlot, x, y, YRange=[0,maxData*1.5], Position=[0.125, 0.125, 0.9, 0.9], $
       XTitle='Time', YTitle='Signal'
       
   ; Save the plotting system variables, so they can be restored after the next plot.
   saveX = !X
   saveY = !Y
   saveP = !P
   
   ; Create the zoomed plot in the upper-right corner of the plot.
   charsize = cgDefCharsize()*0.75
   pos = [0.5, 0.65, 0.85, 0.825]
   cgColorFill, Position=pos, Color='yellow'
   cgPlot, x[zoomIn[0]:zoomIn[1]], y[zoomIn[0]:zoomIn[1]], $
       Position=pos, /NoErase, XStyle=1, Color='Red', Charsize=charsize, $
       PSym=-2, Symcolor='dodger blue', YNoZero=1, Label='Critical Region'
       
   ; Restore the system variables so the Convert_Coord command works on the correct plot.
   !X = saveX
   !Y = saveY
   !P = saveP
   
   ; Draw the zoom box.
   miny = Min(y[zoomIn[0]:zoomIn[1]], Max=maxy)
   coordNormal = Convert_Coord([ x[zoomIn[0]], x[zoomIn[1]] ], [ miny, maxy ], /Data, /To_Normal)
   cgPlotS, [coordNormal[0,0], coordNormal[0,1], coordNormal[0,1], coordNormal[0,0], coordNormal[0,0]], $
       [coordNormal[1,0], coordNormal[1,0], coordNormal[1,1], coordNormal[1,1], coordNormal[1,0]], $
       Thick=(!D.Name EQ 'PS') ? 4 : 2, Color='RED5', /Normal
       
   ; Draw the zoom lines.
   cgPlotS, [coordNormal[0,0], 0.50], [coordNormal[1,1], 0.65], LineStyle=2, Color='blu4', /Normal
   cgPlotS, [coordNormal[0,1], 0.85], [coordNormal[1,1], 0.65], LineStyle=2, Color='blu4', /Normal

END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Plot_Within_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Plot_Within_Plot', WTitle='A Plot within a Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'plot_within_plot.ps'
  Plot_Within_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'plot_within_plot.ps', /PNG, Width=600

END